@@ -2,6 +2,10 @@
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 #include "inputeventitem.h"
+#include <QLoggingCategory>
+namespace {
+Q_LOGGING_CATEGORY(logInputEvent, "dde.launchpad.input")
+}
 
 InputEventItem::InputEventItem()
 {
@@ -11,9 +15,11 @@ InputEventItem::InputEventItem()
 bool InputEventItem::eventFilter(QObject *obj, QEvent *event) {
     if (event->type() == QEvent::InputMethod && (this->children().contains(obj) || obj == this)) {
         QInputMethodEvent *inputMethodEvent = static_cast<QInputMethodEvent *>(event);
-        qDebug() << "InputEventItem::eventFilter: " << inputMethodEvent->commitString();
-        if (!inputMethodEvent->commitString().isEmpty())
+        qCDebug(logInputEvent) << "Input method event received:" << inputMethodEvent->commitString();
+        if (!inputMethodEvent->commitString().isEmpty()) {
+            qCInfo(logInputEvent) << "Emitting input received signal:" << inputMethodEvent->commitString();
             Q_EMIT inputReceived(inputMethodEvent->commitString());
+        }
     }
     return QObject::eventFilter(obj, event);
 }
