@@ -2,72 +2,58 @@
 <context>
     <name>AppItemMenu</name>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="34"/>
         <source>Open</source>
         <translation>開く</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="46"/>
         <source>Pin to Top</source>
         <translation>上部に固定</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="55"/>
         <source>Move to Top</source>
         <translation>上部に移動</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="65"/>
         <source>Remove from favorites</source>
         <translation>お気に入りから削除</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="65"/>
         <source>Add to favorites</source>
         <translation>お気に入りに追加</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="80"/>
         <source>Remove from desktop</source>
         <translation>デスクトップから削除</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="80"/>
         <source>Send to desktop</source>
         <translation>デスクトップに追加</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="91"/>
         <source>Remove from dock</source>
         <translation>ドックから削除</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="91"/>
         <source>Send to dock</source>
         <translation>ドックに固定</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="103"/>
         <source>Remove from startup</source>
         <translation>スタートアップから削除</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="103"/>
         <source>Add to startup</source>
         <translation>スタートアップへ追加</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="111"/>
         <source>Use a proxy</source>
         <translation>プロキシを使う</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="120"/>
         <source>Disable display scaling</source>
         <translation>ディスプレイスケーリングを無効化</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="127"/>
         <source>Uninstall</source>
         <translation>アンインストール</translation>
     </message>
@@ -75,17 +61,14 @@
 <context>
     <name>BottomBar</name>
     <message>
-        <location filename="../../qml/windowed/BottomBar.qml" line="33"/>
         <source>Power</source>
         <translation>電源</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/BottomBar.qml" line="62"/>
         <source>Search</source>
         <translation>検索</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/BottomBar.qml" line="109"/>
         <source>Full-screen Mode</source>
         <translation>全画面モード</translation>
     </message>
@@ -93,12 +76,10 @@
 <context>
     <name>DummyAppItemMenu</name>
     <message>
-        <location filename="../../qml/DummyAppItemMenu.qml" line="27"/>
         <source>Install</source>
         <translation>インストール</translation>
     </message>
     <message>
-        <location filename="../../qml/DummyAppItemMenu.qml" line="34"/>
         <source>Remove</source>
         <translation>削除</translation>
     </message>
@@ -106,7 +87,6 @@
 <context>
     <name>FrequentlyUsedView</name>
     <message>
-        <location filename="../../qml/windowed/FrequentlyUsedView.qml" line="36"/>
         <source>Frequently Used</source>
         <translation>最近使用したもの</translation>
     </message>
@@ -114,7 +94,6 @@
 <context>
     <name>FullscreenFrame</name>
     <message>
-        <location filename="../../qml/FullscreenFrame.qml" line="254"/>
         <source>Window Mode</source>
         <translation>ウィンドウ モード</translation>
     </message>
@@ -122,72 +101,58 @@
 <context>
     <name>Main</name>
     <message>
-        <location filename="../../qml/Main.qml" line="22"/>
         <source>Internet</source>
         <translation>インターネット</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="24"/>
         <source>Chat</source>
         <translation>チャット</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="26"/>
         <source>Music</source>
         <translation>ミュージック</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="28"/>
         <source>Video</source>
         <translation>ビデオ</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="30"/>
         <source>Graphics</source>
         <translation>グラフィックス</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="32"/>
         <source>Games</source>
         <translation>ゲーム</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="34"/>
         <source>Office</source>
         <translation>オフィス</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="36"/>
         <source>Reading</source>
         <translation>文書</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="38"/>
         <source>Development</source>
         <translation>開発</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="40"/>
         <source>System</source>
         <translation>システム</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="42"/>
         <source>Others</source>
         <translation>その他</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="400"/>
         <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
         <translation>%1 をアンインストールしてもよろしいですか？</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="412"/>
         <source>Cancel</source>
         <translation>キャンセル</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="426"/>
         <source>Confirm</source>
         <translation>確認</translation>
     </message>
@@ -195,7 +160,6 @@
 <context>
     <name>RecentlyInstalledView</name>
     <message>
-        <location filename="../../qml/windowed/RecentlyInstalledView.qml" line="34"/>
         <source>Recently Installed</source>
         <translation>最近インストールされたもの</translation>
     </message>
@@ -203,13 +167,10 @@
 <context>
     <name>SearchResultView</name>
     <message>
-        <location filename="../../qml/windowed/SearchResultView.qml" line="37"/>
         <source>All Apps</source>
         <translation>すべてのアプリ</translation>
     </message>
     <message>
-        <location filename="../../qml/FullscreenFrame.qml" line="557"/>
-        <location filename="../../qml/windowed/SearchResultView.qml" line="102"/>
         <source>No search results</source>
         <translation>検索結果はありません</translation>
     </message>
@@ -217,47 +178,38 @@
 <context>
     <name>SideBar</name>
     <message>
-        <location filename="../../qml/windowed/SideBar.qml" line="40"/>
         <source>Free sorting</source>
         <translation>フリー並び替え</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/SideBar.qml" line="54"/>
         <source>Sort by category</source>
         <translation>カテゴリで並べ替え</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/SideBar.qml" line="66"/>
         <source>Sort by name</source>
         <translation>名前で並べ替え</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/SideBar.qml" line="90"/>
         <source>Sorting Mode</source>
         <translation>並び替えモード</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/SideBar.qml" line="145"/>
         <source>Computer</source>
         <translation>コンピューター</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/SideBar.qml" line="156"/>
         <source>Pictures</source>
         <translation>ピクチャー</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/SideBar.qml" line="167"/>
         <source>Documents</source>
         <translation>ドキュメント</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/SideBar.qml" line="178"/>
         <source>Desktop</source>
         <translation>デスクトップ</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/SideBar.qml" line="189"/>
         <source>Control Center</source>
         <translation>コントロールセンター</translation>
     </message>
@@ -265,77 +217,62 @@
 <context>
     <name>launcheritem</name>
     <message>
-        <location filename="../package/launcheritem.qml" line="111"/>
         <source>Internet</source>
         <translation>インターネット</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="113"/>
         <source>Chat</source>
         <translation>チャット</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="115"/>
         <source>Music</source>
         <translation>ミュージック</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="117"/>
         <source>Video</source>
         <translation>ビデオ</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="119"/>
         <source>Graphics</source>
         <translation>グラフィックス</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="121"/>
         <source>Games</source>
         <translation>ゲーム</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="123"/>
         <source>Office</source>
         <translation>オフィス</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="125"/>
         <source>Reading</source>
         <translation>文書</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="127"/>
         <source>Development</source>
         <translation>開発</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="129"/>
         <source>System</source>
         <translation>システム</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="131"/>
         <source>Others</source>
         <translation>その他</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="162"/>
         <source>launchpad</source>
         <translation>ランチャー</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="309"/>
         <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
         <translation>%1 をアンインストールしてもよろしいですか？</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="321"/>
         <source>Cancel</source>
         <translation>キャンセル</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="335"/>
         <source>Confirm</source>
         <translation>確認</translation>
     </message>
