@@ -2,72 +2,58 @@
 <context>
     <name>AppItemMenu</name>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="34"/>
         <source>Open</source>
         <translation>Aç</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="46"/>
         <source>Pin to Top</source>
         <translation>Üste Sabitle</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="55"/>
         <source>Move to Top</source>
         <translation>Üste Taşı</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="65"/>
         <source>Remove from favorites</source>
         <translation>Favorilerden kaldır</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="65"/>
         <source>Add to favorites</source>
         <translation>Favorilere ekle</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="80"/>
         <source>Remove from desktop</source>
         <translation>Masaüstünden kaldır</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="80"/>
         <source>Send to desktop</source>
         <translation>Masaüstüne gönder</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="91"/>
         <source>Remove from dock</source>
         <translation>Rıhtım&apos;dan kaldır</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="91"/>
         <source>Send to dock</source>
         <translation>Rıhtıma gönder</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="103"/>
         <source>Remove from startup</source>
         <translation>Başlangıçtan kaldır</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="103"/>
         <source>Add to startup</source>
         <translation>Başlangıca ekle</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="111"/>
         <source>Use a proxy</source>
         <translation>Vekil sunucu kullan</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="120"/>
         <source>Disable display scaling</source>
         <translation>Ekran ölçeklendirmeyi devre dışı bırak</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="127"/>
         <source>Uninstall</source>
         <translation>Kaldır</translation>
     </message>
@@ -75,17 +61,14 @@
 <context>
     <name>BottomBar</name>
     <message>
-        <location filename="../../qml/windowed/BottomBar.qml" line="33"/>
         <source>Power</source>
         <translation>Güç</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/BottomBar.qml" line="62"/>
         <source>Search</source>
         <translation>Ara</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/BottomBar.qml" line="109"/>
         <source>Full-screen Mode</source>
         <translation>Tam Ekran Kipi</translation>
     </message>
@@ -93,12 +76,10 @@
 <context>
     <name>DummyAppItemMenu</name>
     <message>
-        <location filename="../../qml/DummyAppItemMenu.qml" line="27"/>
         <source>Install</source>
         <translation>Kur</translation>
     </message>
     <message>
-        <location filename="../../qml/DummyAppItemMenu.qml" line="34"/>
         <source>Remove</source>
         <translation>Kaldır</translation>
     </message>
@@ -106,7 +87,6 @@
 <context>
     <name>FrequentlyUsedView</name>
     <message>
-        <location filename="../../qml/windowed/FrequentlyUsedView.qml" line="36"/>
         <source>Frequently Used</source>
         <translation>Sık kullanılır</translation>
     </message>
@@ -114,7 +94,6 @@
 <context>
     <name>FullscreenFrame</name>
     <message>
-        <location filename="../../qml/FullscreenFrame.qml" line="254"/>
         <source>Window Mode</source>
         <translation>Pencere Kipi</translation>
     </message>
@@ -122,72 +101,58 @@
 <context>
     <name>Main</name>
     <message>
-        <location filename="../../qml/Main.qml" line="22"/>
         <source>Internet</source>
         <translation>İnternet</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="24"/>
         <source>Chat</source>
         <translation>Sohbet</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="26"/>
         <source>Music</source>
         <translation>Müzik</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="28"/>
         <source>Video</source>
         <translation>Video</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="30"/>
         <source>Graphics</source>
         <translation>Grafik</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="32"/>
         <source>Games</source>
         <translation>Oyunlar</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="34"/>
         <source>Office</source>
         <translation>Ofis</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="36"/>
         <source>Reading</source>
         <translation>Okuma</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="38"/>
         <source>Development</source>
         <translation>Geliştirme</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="40"/>
         <source>System</source>
         <translation>Sistem</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="42"/>
         <source>Others</source>
         <translation>Diğerleri</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="400"/>
         <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
         <translation>&quot;%1&quot; öğesini kaldırmak istediğinizden emin misiniz?</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="412"/>
         <source>Cancel</source>
         <translation>İptal</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="426"/>
         <source>Confirm</source>
         <translation>Onayla</translation>
     </message>
@@ -195,7 +160,6 @@
 <context>
     <name>RecentlyInstalledView</name>
     <message>
-        <location filename="../../qml/windowed/RecentlyInstalledView.qml" line="34"/>
         <source>Recently Installed</source>
         <translation>Son zamanlarda yüklenen</translation>
     </message>
@@ -203,13 +167,10 @@
 <context>
     <name>SearchResultView</name>
     <message>
-        <location filename="../../qml/windowed/SearchResultView.qml" line="37"/>
         <source>All Apps</source>
         <translation>Tüm Uygulamalar</translation>
     </message>
     <message>
-        <location filename="../../qml/FullscreenFrame.qml" line="557"/>
-        <location filename="../../qml/windowed/SearchResultView.qml" line="102"/>
         <source>No search results</source>
         <translation>Hiçbir arama sonucu bulunamadı</translation>
     </message>
@@ -217,47 +178,38 @@
 <context>
     <name>SideBar</name>
     <message>
-        <location filename="../../qml/windowed/SideBar.qml" line="40"/>
         <source>Free sorting</source>
         <translation>Serbest sıralama</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/SideBar.qml" line="54"/>
         <source>Sort by category</source>
         <translation>Kategoriye göre sırala</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/SideBar.qml" line="66"/>
         <source>Sort by name</source>
         <translation>İsmime göre sırala</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/SideBar.qml" line="90"/>
         <source>Sorting Mode</source>
         <translation>Sıralama Kipi</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/SideBar.qml" line="145"/>
         <source>Computer</source>
         <translation>Bilgisayar</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/SideBar.qml" line="156"/>
         <source>Pictures</source>
         <translation>Resimler</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/SideBar.qml" line="167"/>
         <source>Documents</source>
         <translation>Belgeler</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/SideBar.qml" line="178"/>
         <source>Desktop</source>
         <translation>Masaüstü</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/SideBar.qml" line="189"/>
         <source>Control Center</source>
         <translation>Kontrol Merkezi</translation>
     </message>
@@ -265,77 +217,62 @@
 <context>
     <name>launcheritem</name>
     <message>
-        <location filename="../package/launcheritem.qml" line="111"/>
         <source>Internet</source>
         <translation>İnternet</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="113"/>
         <source>Chat</source>
         <translation>Sohbet</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="115"/>
         <source>Music</source>
         <translation>Müzik</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="117"/>
         <source>Video</source>
         <translation>Video</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="119"/>
         <source>Graphics</source>
         <translation>Grafik</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="121"/>
         <source>Games</source>
         <translation>Oyunlar</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="123"/>
         <source>Office</source>
         <translation>Ofis</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="125"/>
         <source>Reading</source>
         <translation>Okuma</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="127"/>
         <source>Development</source>
         <translation>Geliştirme</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="129"/>
         <source>System</source>
         <translation>Sistem</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="131"/>
         <source>Others</source>
         <translation>Diğerleri</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="162"/>
         <source>launchpad</source>
         <translation>başlatma</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="309"/>
         <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
         <translation>&quot;%1&quot; öğesini kaldırmak istediğinizden emin misiniz?</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="321"/>
         <source>Cancel</source>
         <translation>İptal</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="335"/>
         <source>Confirm</source>
         <translation>Onayla</translation>
     </message>
